/***************************************************************************
                          xslt_parser.cpp  -  description
                             -------------------
    begin                : Mar 28 2007
    author               : 2007 jiri Tyr
    email                : jiri.tyr@vslib.cz
 ***************************************************************************/
 /***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "plugin_katesymbolviewer.h"

void KatePluginSymbolViewerView::parseXsltSymbols(void) {
	if (!win->viewManager()->activeView()) {
		return;
	}

	popup->changeItem( popup->idAt(2),i18n("Show Params"));
	popup->changeItem( popup->idAt(3),i18n("Show Variables"));
	popup->changeItem( popup->idAt(4),i18n("Show Templates"));

	QString cl; // Current Line
	QString stripped;

	char comment = 0;
	char templ = 0;

	QPixmap cls( ( const char** ) class_xpm );
	QPixmap sct( ( const char** ) struct_xpm );
	QPixmap mcr( ( const char** ) macro_xpm );
	QPixmap cls_int( ( const char** ) class_int_xpm );

	QListViewItem *node = NULL;
	QListViewItem *mcrNode = NULL, *sctNode = NULL, *clsNode = NULL;
	QListViewItem *lastMcrNode = NULL, *lastSctNode = NULL, *lastClsNode = NULL;

	Kate::Document *kv = win->viewManager()->activeView()->getDoc();
	//kdDebug(13000)<<"Lines counted :"<<kv->numLines()<<endl;


	if(treeMode) {
		mcrNode = new QListViewItem(symbols, symbols->lastItem(), i18n("Params"));
		sctNode = new QListViewItem(symbols, symbols->lastItem(), i18n("Variables"));
		clsNode = new QListViewItem(symbols, symbols->lastItem(), i18n("Templates"));

		mcrNode->setPixmap(0, (const QPixmap &)mcr);
		sctNode->setPixmap(0, (const QPixmap &)sct);
		clsNode->setPixmap(0, (const QPixmap &)cls);

		if (expanded_on) {
			mcrNode->setOpen(TRUE);
			sctNode->setOpen(TRUE);
			clsNode->setOpen(TRUE);
		}

		lastMcrNode = mcrNode;
		lastSctNode = sctNode;
		lastClsNode = clsNode;

		symbols->setRootIsDecorated(1);
	} else {
		symbols->setRootIsDecorated(0);
	}

	for (unsigned int i=0; i<kv->numLines(); i++) {
		cl = kv->textLine(i);
		cl = cl.stripWhiteSpace();

		if(cl.find(QRegExp("<!--")) >= 0) {
			comment = 1;
		}
		if(cl.find(QRegExp("-->")) >= 0) {
			comment = 0;
			continue;
		}

		if(cl.find(QRegExp("^</xsl:template>")) >= 0) {
			templ = 0;
			continue;
		}

		if (comment==1) {
			continue;
		}
		if (templ==1) {
			continue;
		}

		if(cl.find(QRegExp("^<xsl:param ")) == 0 && macro_on) {
			QString stripped = cl.replace(QRegExp("^<xsl:param +name=\""), "");
			stripped = stripped.replace(QRegExp("\".*"), "");

			if (treeMode) {
				node = new QListViewItem(mcrNode, lastMcrNode, stripped);
				lastMcrNode = node;
			} else {
				node = new QListViewItem(symbols, symbols->lastItem(), stripped);
			}

			node->setPixmap(0, (const QPixmap &) mcr);
			node->setText(1, QString::number(i, 10));
		}

		if(cl.find(QRegExp("^<xsl:variable ")) == 0 && struct_on) {
			QString stripped = cl.replace(QRegExp("^<xsl:variable +name=\""), "");
			stripped = stripped.replace(QRegExp("\".*"), "");

			if (treeMode) {
				node = new QListViewItem(sctNode, lastSctNode, stripped);
				lastSctNode = node;
			} else {
				node = new QListViewItem(symbols, symbols->lastItem(), stripped);
			}

			node->setPixmap(0, (const QPixmap &) sct);
			node->setText(1, QString::number(i, 10));
		}

		if(cl.find(QRegExp("^<xsl:template +match=")) == 0 && func_on) {
			QString stripped = cl.replace(QRegExp("^<xsl:template +match=\""), "");
			stripped = stripped.replace(QRegExp("\".*"), "");

			if (treeMode) {
				node = new QListViewItem(clsNode, lastClsNode, stripped);
				lastClsNode = node;
			} else {
				node = new QListViewItem(symbols, symbols->lastItem(), stripped);
			}

			node->setPixmap(0, (const QPixmap &) cls_int);
			node->setText(1, QString::number(i, 10));
		}

		if(cl.find(QRegExp("^<xsl:template +name=")) == 0 && func_on) {
			QString stripped = cl.replace(QRegExp("^<xsl:template +name=\""), "");
			stripped = stripped.replace(QRegExp("\".*"), "");

			if (treeMode) {
				node = new QListViewItem(clsNode, lastClsNode, stripped);
				lastClsNode = node;
			} else {
				node = new QListViewItem(symbols, symbols->lastItem(), stripped);
			}

			node->setPixmap(0, (const QPixmap &) cls);
			node->setText(1, QString::number(i, 10));
		}

		if(cl.find(QRegExp("<xsl:template")) >= 0) {
			templ = 1;
		}
    }
}
